Compatibility names for the canonical server wall-clock contract. Compatibility names for the canonical server wall-clock contract.
Structs
- Deterministic
Gateway Clock - Thread-safe
WallClockthat advances by a fixed step on each observation. - Deterministic
Wall Clock - Thread-safe
WallClockthat advances by a fixed step on each observation. - System
Gateway Clock WallClockbacked by the host system clock.- System
Wall Clock WallClockbacked by the host system clock.- Wall
Timestamp - One observed host wall-clock instant, represented as milliseconds since the Unix epoch.
Traits
- Gateway
Clock - Object-safe source of host wall-clock observations.
- Wall
Clock - Object-safe source of host wall-clock observations.