pub struct GatewayEventData { /* private fields */ }Expand description
Decoded gateway event payload: sequence number, event kind, and body.
Implementations
Sourceimpl GatewayEventData
impl GatewayEventData
Sourcepub fn from_event(event: &GatewayEvent) -> Self
pub fn from_event(event: &GatewayEvent) -> Self
Extracts the streaming-relevant fields from a GatewayEvent.
Sourcepub fn from_packet(packet: &StreamPacket) -> Result<Self>
pub fn from_packet(packet: &StreamPacket) -> Result<Self>
Decodes gateway event data from a stream data packet, erroring if the packet is not a data packet of the gateway event kind.