content_id_for_expr

Function content_id_for_expr 

pub fn content_id_for_expr(expr: &Expr) -> Result<ContentId>
Computes the content id of an arbitrary expression by encoding it to a binary frame and hashing the resulting bytes.