Installation glue that registers the gateway library with a runtime.
Functions
- install_
openai_ gateway_ lib - Installs the OpenAI gateway library into the context, idempotently.
Installation glue that registers the gateway library with a runtime.