Module ops

Module ops 

Gateway operations exposed to the runtime as callable functions.

Structs

OpenAiGatewayFunction
Callable runtime function exposing one gateway operation to the runtime.

Functions

cache_stats_symbol
Returns the openai-gateway/cache-stats operation symbol.
capability_report_symbol
Returns the openai-gateway/capability-report operation symbol.
events_symbol
Returns the openai-gateway/events operation symbol.
fabric_symbol
Returns the openai-gateway/fabric operation symbol.
health_symbol
Returns the openai-gateway/health operation symbol.
key_add_symbol
Returns the openai-gateway/key-add operation symbol.
key_list_symbol
Returns the openai-gateway/key-list operation symbol.
model_health_symbol
Returns the openai-gateway/model-health operation symbol.
models_symbol
Returns the openai-gateway/models operation symbol.
plan_check_symbol
Returns the openai-gateway/plan-check operation symbol.
plan_combinators_symbol
Returns the openai-gateway/plan-combinators operation symbol.
plan_explain_symbol
Returns the openai-gateway/plan-explain operation symbol.
plan_parse_symbol
Returns the openai-gateway/plan-parse operation symbol.
plan_run_symbol
Returns the openai-gateway/plan-run operation symbol.
run_get_symbol
Returns the openai-gateway/run-get operation symbol.
runs_symbol
Returns the openai-gateway/runs operation symbol.
serve_symbol
Returns the openai-gateway/serve operation symbol.
storage_stats_symbol
Returns the openai-gateway/storage-stats operation symbol.