pub fn eval_plan_report_with_cache(
cx: &mut Cx,
plan: &Expr,
request: &Expr,
cache: &mut OpenAiPlanCache,
) -> Result<PlanEvalReport>Expand description
Evaluates a plan with a plan cache available for plan/cache combinators.
pub fn eval_plan_report_with_cache(
cx: &mut Cx,
plan: &Expr,
request: &Expr,
cache: &mut OpenAiPlanCache,
) -> Result<PlanEvalReport>Evaluates a plan with a plan cache available for plan/cache combinators.