pub fn check_plan_with_limits(plan: &Expr, limits: PlanLimits) -> Result<()>Expand description
Validates a plan expression against the supplied structural limits.
pub fn check_plan_with_limits(plan: &Expr, limits: PlanLimits) -> Result<()>Validates a plan expression against the supplied structural limits.