pub fn retrieve_thread<S>(store: &S, thread_id: &str) -> GatewayResponsewhere
S: GatewayStateStore,Expand description
Returns the JSON object for a stored thread, or a not-found error response.
pub fn retrieve_thread<S>(store: &S, thread_id: &str) -> GatewayResponsewhere
S: GatewayStateStore,Returns the JSON object for a stored thread, or a not-found error response.