pub fn grant_capability_set(
seat: &GrantSeat,
cx: &mut Cx,
capabilities: &CapabilitySet,
)Expand description
Grants every capability in capabilities to cx, through the host-held
seat minted when cx was constructed.
pub fn grant_capability_set(
seat: &GrantSeat,
cx: &mut Cx,
capabilities: &CapabilitySet,
)Grants every capability in capabilities to cx, through the host-held
seat minted when cx was constructed.