Module tool_loop

Module tool_loop 

Multi-round tool-call loop driving model runs that invoke tools.

Structs

ToolLoopConfig
Bounds on the multi-round tool-call loop.

Functions

run_tool_loop_with_cache
Runs the tool loop using the tool registry parsed from request_object.
run_tool_loop_with_registry
Drives the model/tool loop until the model stops requesting tool calls.