pub struct GatewayRoute { /* private fields */ }Expand description
A single registered route: an HTTP method, a path matcher, and a handler.
Implementations
Sourceimpl GatewayRoute
impl GatewayRoute
Sourcepub fn new(
method: &'static str,
path: &'static str,
handler: fn(&GatewayRequest, &GatewayRouteState) -> GatewayResponse,
) -> Self
pub fn new( method: &'static str, path: &'static str, handler: fn(&GatewayRequest, &GatewayRouteState) -> GatewayResponse, ) -> Self
Returns a route matching path exactly for the given method and handler.
Sourcepub fn prefix(
method: &'static str,
display_path: &'static str,
prefix: &'static str,
handler: fn(&GatewayRequest, &GatewayRouteState) -> GatewayResponse,
) -> Self
pub fn prefix( method: &'static str, display_path: &'static str, prefix: &'static str, handler: fn(&GatewayRequest, &GatewayRouteState) -> GatewayResponse, ) -> Self
Returns a route matching any path that starts with prefix.
display_path is the canonical path reported by GatewayRoute::path.
Sourcepub fn prefix_suffix(
method: &'static str,
display_path: &'static str,
prefix: &'static str,
suffix: &'static str,
handler: fn(&GatewayRequest, &GatewayRouteState) -> GatewayResponse,
) -> Self
pub fn prefix_suffix( method: &'static str, display_path: &'static str, prefix: &'static str, suffix: &'static str, handler: fn(&GatewayRequest, &GatewayRouteState) -> GatewayResponse, ) -> Self
Returns a route matching paths that start with prefix and end with suffix.
display_path is the canonical path reported by GatewayRoute::path.