pub struct GatewayFile { /* private fields */ }Expand description
A gateway file record: its metadata plus a reference to where its bytes live.
Implementations
Sourceimpl GatewayFile
impl GatewayFile
Sourcepub fn new(
id: impl Into<String>,
filename: impl Into<String>,
purpose: impl Into<String>,
bytes: u64,
created_at_ms: u64,
storage_ref: GatewayFileStorageRef,
) -> Self
pub fn new( id: impl Into<String>, filename: impl Into<String>, purpose: impl Into<String>, bytes: u64, created_at_ms: u64, storage_ref: GatewayFileStorageRef, ) -> Self
Creates a file record with the given metadata and storage reference.
Sourcepub fn purpose(&self) -> &str
pub fn purpose(&self) -> &str
Returns the declared purpose of the file (e.g. "batch", "assistants").
Sourcepub fn created_at_ms(&self) -> u64
pub fn created_at_ms(&self) -> u64
Returns the creation timestamp in milliseconds since the Unix epoch.
Sourcepub fn storage_ref(&self) -> &GatewayFileStorageRef
pub fn storage_ref(&self) -> &GatewayFileStorageRef
Returns a reference to where the file’s bytes are stored.