pub struct GatewayThreadMessage { /* private fields */ }Expand description
A single message belonging to a GatewayThread.
Implementations
Sourceimpl GatewayThreadMessage
impl GatewayThreadMessage
Sourcepub fn new(
id: impl Into<String>,
thread_id: impl Into<String>,
role: impl Into<String>,
content: impl Into<String>,
created_at_ms: u64,
) -> Self
pub fn new( id: impl Into<String>, thread_id: impl Into<String>, role: impl Into<String>, content: impl Into<String>, created_at_ms: u64, ) -> Self
Creates a thread message with the given id, thread, role, content, and time.
Sourcepub fn created_at_ms(&self) -> u64
pub fn created_at_ms(&self) -> u64
Returns the creation timestamp in milliseconds since the Unix epoch.