GatewayResponseObjectStore

Trait GatewayResponseObjectStore 

pub trait GatewayResponseObjectStore {
    // Required methods
    fn put_response_object(
        &mut self,
        response: StoredGatewayResponse,
    ) -> Result<()>;
    fn response_object(
        &self,
        response_id: &str,
    ) -> Option<StoredGatewayResponse>;
}
Store for response objects keyed by their public response id.

Required Methods

fn put_response_object(&mut self, response: StoredGatewayResponse) -> Result<()>

Stores a response object, replacing any existing entry with the same id.

fn response_object(&self, response_id: &str) -> Option<StoredGatewayResponse>

Returns the response object with the given id, if present.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors