Module vector

Module vector 

Vector-store record kinds for the gateway.

Structs

GatewayVectorStore
A named gateway vector store holding embedded text items.
GatewayVectorStoreItem
A single embedded text item within a GatewayVectorStore.

Constants

GATEWAY_VECTOR_STORE_ITEM_KIND
Record kind tag designating a single item within a gateway vector store.
GATEWAY_VECTOR_STORE_KIND
Record kind tag designating a gateway vector store.