pub struct GatewayVectorStore { /* private fields */ }Expand description
A named gateway vector store holding embedded text items.
Implementations
Sourceimpl GatewayVectorStore
impl GatewayVectorStore
Sourcepub fn new(
id: impl Into<String>,
name: impl Into<String>,
created_at_ms: u64,
items: Vec<GatewayVectorStoreItem>,
) -> Self
pub fn new( id: impl Into<String>, name: impl Into<String>, created_at_ms: u64, items: Vec<GatewayVectorStoreItem>, ) -> Self
Creates a vector store with the given id, name, creation time, and items.
Sourcepub fn created_at_ms(&self) -> u64
pub fn created_at_ms(&self) -> u64
Returns the creation timestamp in milliseconds since the Unix epoch.
Sourcepub fn items(&self) -> &[GatewayVectorStoreItem]
pub fn items(&self) -> &[GatewayVectorStoreItem]
Returns the items held by this vector store.