Module clock

Module clock 

Compatibility names for the canonical server wall-clock contract. Compatibility names for the canonical server wall-clock contract.

Structs

DeterministicGatewayClock
Thread-safe WallClock that advances by a fixed step on each observation.
DeterministicWallClock
Thread-safe WallClock that advances by a fixed step on each observation.
SystemGatewayClock
WallClock backed by the host system clock.
SystemWallClock
WallClock backed by the host system clock.
WallTimestamp
One observed host wall-clock instant, represented as milliseconds since the Unix epoch.

Traits

GatewayClock
Object-safe source of host wall-clock observations.
WallClock
Object-safe source of host wall-clock observations.