OpenAI JSON codec surface: decode, encode, streaming, and shared shapes.
Re-exports
pub use decode::decode_openai_request;pub use decode::decode_openai_response;pub use encode::encode_openai_request;pub use encode::encode_openai_response;pub use encode::encode_openai_responses_response;pub use shapes::ChatTranscript;pub use shapes::OpenAiCodecOptions;pub use shapes::OpenAiRequestOptions;pub use streaming::GatewayEventData;pub use streaming::OpenAiSseSurface;pub use streaming::StreamSink;pub use streaming::encode_gateway_events_sse;pub use streaming::gateway_event_data_from_packet;pub use streaming::gateway_event_data_kind;pub use streaming::gateway_event_data_packets;
Modules
- decode
- Decoding of OpenAI request/response JSON into SIM transcript expressions.
- encode
- Encoding of SIM transcript expressions into OpenAI request/response JSON.
- shapes
- Validated transcript and codec-option shapes for the OpenAI codec.
- streaming
- Server-sent-event streaming of gateway events on OpenAI surfaces.
Structs
- Open
AiCodec - Runtime codec for OpenAI-compatible chat-completion JSON fixtures.
Functions
- install_
openai_ codec - Registers the OpenAI codec with the linker, resolving its expression and options shapes and installing it as a runtime codec value.
- openai_
codec_ symbol - Returns the codec symbol
codec/openai.