Content-id helpers that normalize and hash gateway request expressions.
Constants
- VOLATILE_
REQUEST_ FIELDS - Field names stripped from a request before computing its content id.
Functions
- content_
id_ for_ expr - Computes the content id of an arbitrary expression by encoding it to a binary frame and hashing the resulting bytes.
- normalize_
request_ expr - Returns a copy of a request map with
VOLATILE_REQUEST_FIELDSremoved. - request_
content_ id - Computes the content id of a
GatewayRequest, ignoring volatile fields. - request_
expr_ content_ id - Computes the content id of a request expression after normalizing away its volatile fields.