Gateway operations exposed to the runtime as callable functions.
Structs
- Open
AiGateway Function - Callable runtime function exposing one gateway operation to the runtime.
Functions
- cache_
stats_ symbol - Returns the
openai-gateway/cache-statsoperation symbol. - capability_
report_ symbol - Returns the
openai-gateway/capability-reportoperation symbol. - events_
symbol - Returns the
openai-gateway/eventsoperation symbol. - fabric_
symbol - Returns the
openai-gateway/fabricoperation symbol. - health_
symbol - Returns the
openai-gateway/healthoperation symbol. - key_
add_ symbol - Returns the
openai-gateway/key-addoperation symbol. - key_
list_ symbol - Returns the
openai-gateway/key-listoperation symbol. - model_
health_ symbol - Returns the
openai-gateway/model-healthoperation symbol. - models_
symbol - Returns the
openai-gateway/modelsoperation symbol. - plan_
check_ symbol - Returns the
openai-gateway/plan-checkoperation symbol. - plan_
combinators_ symbol - Returns the
openai-gateway/plan-combinatorsoperation symbol. - plan_
explain_ symbol - Returns the
openai-gateway/plan-explainoperation symbol. - plan_
parse_ symbol - Returns the
openai-gateway/plan-parseoperation symbol. - plan_
run_ symbol - Returns the
openai-gateway/plan-runoperation symbol. - run_
get_ symbol - Returns the
openai-gateway/run-getoperation symbol. - runs_
symbol - Returns the
openai-gateway/runsoperation symbol. - serve_
symbol - Returns the
openai-gateway/serveoperation symbol. - storage_
stats_ symbol - Returns the
openai-gateway/storage-statsoperation symbol.