Multi-round tool-call loop driving model runs that invoke tools.
Structs
- Tool
Loop Config - Bounds on the multi-round tool-call loop.
Functions
- run_
tool_ loop_ with_ cache - Runs the tool loop using the tool registry parsed from
request_object. - run_
tool_ loop_ with_ registry - Drives the model/tool loop until the model stops requesting tool calls.