pub struct StoredGatewayResponse { /* private fields */ }Expand description
A stored response object linking a response id to its content-addressed
GatewayResponse and the records that produced it.
Implementations
Sourceimpl StoredGatewayResponse
impl StoredGatewayResponse
Sourcepub fn new(
response_id: impl Into<String>,
content_id: ContentId,
response: GatewayResponse,
) -> Self
pub fn new( response_id: impl Into<String>, content_id: ContentId, response: GatewayResponse, ) -> Self
Creates a stored response with no linked request, run, events, or parent.
Sourcepub fn response_id(&self) -> &str
pub fn response_id(&self) -> &str
Returns the public response identifier.
Sourcepub fn content_id(&self) -> &ContentId
pub fn content_id(&self) -> &ContentId
Returns the content id of the stored GatewayResponse.
Sourcepub fn response(&self) -> &GatewayResponse
pub fn response(&self) -> &GatewayResponse
Returns the stored response value.